@@ -615,7 +615,7 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
    ($stdout,$stderr)=$handle->cmd($sudo.
       'chmod -v 777 fullauto_clickable_image.png','__display__');
    ($stdout,$stderr)=$handle->cwd('~');
-   my $sd='/var/www/gnusocial/theme/base';
+   my $sd='/var/www/gnusocial/theme/neo-gnu';
    ($stdout,$stderr)=$handle->cmd($sudo.
       "mv -vf fullauto_clickable_image.png $sd",'__display__');
    ($stdout,$stderr)=$local->cmd($sudo.
@@ -624,7 +624,7 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
       "        array(%SQ%url%SQ% => %SQ%http://www.fullauto.com%SQ%,%NL%".
       "              %SQ%title%SQ% => %SQ%FullAuto - Automates EVERYTHING%SQ%,%NL%".
       "              %SQ%image%SQ% => %NL%".
-      "\$_path.%SQ%/theme/base/fullauto_clickable_image.png%SQ%),%NL%";
+      "\$_path.%SQ%/theme/neo-gnu/fullauto_clickable_image.png%SQ%),%NL%";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
       "\'/cc_by_3.0_80x15/a$ad\' /var/www/gnusocial/lib/default.php");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
@@ -664,9 +664,9 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
       "${sudo}sed -i 's#\\(^function showFullAuto[(][)]$\\\)#    \\1#' ".
       '/var/www/gnusocial/lib/action.php');
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
-      "\'/showContentLic/ashowFullAuto();\' /var/www/gnusocial/lib/action.php");
+      "\'/-[>]showContentLic/a\$this->showFullAuto();\' /var/www/gnusocial/lib/action.php");
    $handle->cmd_raw(
-      "${sudo}sed -i 's#\\(^showFullAuto[(][)]$\\\)#    \\1#' ".
+      "${sudo}sed -i 's#\\(^\$this-[>]showFullAuto[(][)]$\\\)#    \\1#' ".
       '/var/www/gnusocial/lib/action.php');
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
