@@ -208,19 +208,26 @@ END
    my $mdns=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicDnsName};
    my $pbip=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicIpAddress};
    my $dcnt=0;
+   my $extn='';
    while (1) {
       ($stdout,$stderr)=$handle->cmd("wget --random-wait -qO- ".
          "http://sourceforge.net/projects/phpldapadmin/files");
       $stdout=~s/^.*latest\/download.*?title="(.*?):.*$/$1/s;
+      $extn=$stdout;
       ($stdout,$stderr)=$handle->cmd('sudo '.
          "wget --random-wait --progress=dot ".
-         "http://sourceforge.net/projects/phpldapadmin/files$stdout",
+         "http://sourceforge.net/projects/phpldapadmin/files$extn",
          '__display__');
       next if (-1<index $stderr,'ERROR 404') && $dcnt++<3;
       last
    }
-   ($stdout,$stderr)=$handle->cmd("sudo tar zxvf *tgz",'__display__');
-   ($stdout,$stderr)=$handle->cmd("sudo rm -vf *tgz",'__display__');
+   if ($extn=~/zip/) {
+      ($stdout,$stderr)=$handle->cmd("sudo unzip *zip",'__display__');
+      ($stdout,$stderr)=$handle->cmd("sudo rm -vf *zip",'__display__');
+   } else {
+      ($stdout,$stderr)=$handle->cmd("sudo tar zxvf *tgz",'__display__');
+      ($stdout,$stderr)=$handle->cmd("sudo rm -vf *tgz",'__display__');
+   }
    ($stdout,$stderr)=$handle->cmd("sudo mv -T phpldapadmin* phpldapadmin",
       '__display__');
    ($stdout,$stderr)=$handle->cmd(
